==> pypdf-3.15.3.gh.tar.gz: pypdf-3.15.3/CONTRIBUTORS.md <==
# Contributors

pypdf had a lot of contributors since it started with pyPdf in 2005. We are
a free software project without any company affiliation. We cannot pay
contributors, but we do value their contributions. A lot of time, effort, and
expertise went into this project. With this list, we recognize those awesome
people 🤗

The list is definitely not complete. You can find more contributors via the git
history and [GitHubs 'Contributors' feature](https://github.com/py-pdf/pypdf/graphs/contributors).

## Contributors to the pypdf (formerly pyPdf / PyPDF2) project

* [abyesilyurt](https://github.com/abyesilyurt)
* [ArkieCoder](https://github.com/ArkieCoder)
* [Clauss, Christian](https://github.com/cclauss)
* [DL6ER](https://github.com/DL6ER)
* [ediamondscience](https://github.com/ediamondscience)
* [Ermeson, Felipe](https://github.com/FelipeErmeson)
* [Freitag, François](https://github.com/francoisfreitag)
* [Górny, Michał](https://github.com/mgorny)
* [Grillo, Miguel](https://github.com/Ineffable22)
* [Gutteridge, David H.](https://github.com/dhgutteridge)
* [Hale, Joseph](https://github.com/thehale)
* [harshhes](https://github.com/harshhes)
* [JianzhengLuo](https://github.com/JianzhengLuo)
* [Karvonen, Harry](https://github.com/Hatell/)
* [King, Hunter](https://github.com/neversphere)
* [Kotler, Mitchell](https://github.com/mitchelljkotler)
* [KourFrost](https://github.com/KourFrost)
* [Lightup1](https://github.com/Lightup1)
* [Majumder, Jonah](https://github.com/jonahmajumder)
* [Manini, Lorenzo](https://github.com/lorenzomanini)
* [maxbeer99](https://github.com/maxbeer99)
* [nalin-udhaar](https://github.com/nalin-udhaar)
* [McNeil, Karen](https://github.com/karenlmcneil): Arabic Language Support
* [Mérino, Antoine](https://github.com/Merinorus)
* [Paternault, Louis](https://framagit.org/spalax)
* [Perrensen, Olsen](https://github.com/olsonperrensen)
* [Pinheiro, Arthur](https://github.com/xilopaint)
* [Poddar, Arka](https://github.com/postmeback)
* [programmarchy](https://github.com/programmarchy)
* [pubpub-zz](https://github.com/pubpub-zz): involved in community development
* [Ramos, Leodanis Pozo](https://github.com/lpozo)
* [RitchieP](https://github.com/RitchieP) | [LinkedIn](https://www.linkedin.com/in/ritchie-p-892b31115/) | [StackOverflow](https://stackoverflow.com/users/13328625/casual-r?tab=profile)
* [Rogmann, Sascha](https://github.com/srogmann)
* [robbiebusinessacc](https://github.com/robbiebusinessacc)
* [Roder, Thomas](https://github.com/MrTomRod)
* [Röthenbacher, Thomas](https://github.com/troethe)
* [sietzeberends](https://github.com/sietzeberends)
* [Stüber, Timo](https://github.com/omit66)
* [Thoma, Martin](https://github.com/MartinThoma): Maintainer of pypdf since April 2022. I hope to build a great community with many awesome contributors. [LinkedIn](https://www.linkedin.com/in/martin-thoma/) | [StackOverflow](https://stackoverflow.com/users/562769/martin-thoma) | [Blog](https://martin-thoma.com/)
* [Thomas, Reuben](https://github.com/rrthomas)
* [WevertonGomes](https://github.com/WevertonGomesCosta)
* [Wilson, Huon](https://github.com/huonw)
* ztravis

## Adding a new contributor

Contributors are:

* Anybody who has an commit in main - no matter how big/small or how many. Also if it's via co-authored-by.
* People who opened helpful issues:
  (1) Bugs: with complete MCVE
  (2) Well-described feature requests
  (3) Potentially some more.
  The maintainers of pypdf have the last call on that one.
* Community work: This is exceptional. If the maintainers of pypdf see people
  being super helpful in answering issues / discussions or being very active on
  Stackoverflow, we also consider them being contributors to pypdf.

Contributors can add themselves or ask via an Github Issue to be added.

Please use the following format:

```
* Last name, First name: 140-characters of text; links to linkedin / github / other profiles and personal pages are ok

OR

* GitHub Username: 140-characters of text; links to linkedin / github / other profiles and personal pages are ok
```

and add the entry in the alphabetical order. People who . The 140 characters are everything visible after the `Name:`.

Please don't use images.

==> pypdf-4.3.1.gh.tar.gz: pypdf-4.3.1/CONTRIBUTORS.md <==
# Contributors

pypdf had a lot of contributors since it started as pyPdf in 2005. We are
a free software project without any company affiliation. We cannot pay
contributors, but we do value their contributions. A lot of time, effort, and
expertise went into this project. With this list, we recognize these awesome
people 🤗

The list is definitely not complete. You can find more contributors via the git
history and [GitHub's 'Contributors' feature](https://github.com/py-pdf/pypdf/graphs/contributors).

## Contributors to the pypdf (formerly pyPdf / PyPDF2) project

* [abyesilyurt](https://github.com/abyesilyurt)
* [ArkieCoder](https://github.com/ArkieCoder)
* [Clauss, Christian](https://github.com/cclauss)
* [DL6ER](https://github.com/DL6ER)
* [Duy, Phan Thanh](https://github.com/zuypt)
* [ediamondscience](https://github.com/ediamondscience)
* [Ermeson, Felipe](https://github.com/FelipeErmeson)
* [Freitag, François](https://github.com/francoisfreitag)
* [Górny, Michał](https://github.com/mgorny)
* [Grillo, Miguel](https://github.com/Ineffable22)
* [Gutteridge, David H.](https://github.com/dhgutteridge)
* [Hale, Joseph](https://github.com/thehale)
* [harshhes](https://github.com/harshhes)
* [JianzhengLuo](https://github.com/JianzhengLuo)
* [Karvonen, Harry](https://github.com/Hatell/)
* [King, Hunter](https://github.com/neversphere)
* [Kotler, Mitchell](https://github.com/mitchelljkotler)
* [KourFrost](https://github.com/KourFrost)
* [Lightup1](https://github.com/Lightup1)
* [Majumder, Jonah](https://github.com/jonahmajumder)
* [Manini, Lorenzo](https://github.com/lorenzomanini)
* [maxbeer99](https://github.com/maxbeer99)
* [McNeil, Karen](https://github.com/karenlmcneil): Arabic Language Support
* [Mérino, Antoine](https://github.com/Merinorus)
* [nalin-udhaar](https://github.com/nalin-udhaar)
* [Paramonov, Alexey](https://github.com/alexey-v-paramonov)
* [Paternault, Louis](https://framagit.org/spalax)
* [Perrensen, Olsen](https://github.com/olsonperrensen)
* [pilotandy](https://github.com/pilotandy)
* [Pinheiro, Arthur](https://github.com/xilopaint)
* [pmiller66](https://github.com/pmiller66)
* [Poddar, Arka](https://github.com/postmeback)
* [programmarchy](https://github.com/programmarchy)
* [pubpub-zz](https://github.com/pubpub-zz): involved in community development
* [Ramos, Leodanis Pozo](https://github.com/lpozo)
* [RitchieP](https://github.com/RitchieP) | [LinkedIn](https://www.linkedin.com/in/ritchie-p-892b31115/) | [StackOverflow](https://stackoverflow.com/users/13328625/casual-r?tab=profile)
* [robbiebusinessacc](https://github.com/robbiebusinessacc)
* [Roder, Thomas](https://github.com/MrTomRod)
* [Rogmann, Sascha](https://github.com/srogmann)
* [Röthenbacher, Thomas](https://github.com/troethe)
* [shartzog](https://github.com/shartzog)
* [stefan6419846](https://github.com/stefan6419846)
* [sietzeberends](https://github.com/sietzeberends)
* [Stober, Marc](https://github.com/marcstober)
* [Stüber, Timo](https://github.com/omit66)
* [Thoma, Martin](https://github.com/MartinThoma): Maintainer of pypdf since April 2022. I hope to build a great community with many awesome contributors. [LinkedIn](https://www.linkedin.com/in/martin-thoma/) | [StackOverflow](https://stackoverflow.com/users/562769/martin-thoma) | [Blog](https://martin-thoma.com/)
* [Thomas, Reuben](https://github.com/rrthomas)
* [Tobeabellwether](https://github.com/Tobeabellwether)
* [WevertonGomes](https://github.com/WevertonGomesCosta)
* [Wilson, Huon](https://github.com/huonw)
* ztravis

## Adding a new contributor

Contributors are:

* Anybody who has an commit in `main` - no matter how big/small or how many. Also if it's via *co-authored-by*.
* People who opened helpful issues:

  1. Bugs: with complete MCVE
  2. Well-described feature requests
  3. Potentially some more.

  The maintainers of pypdf have the last call on that one.
* Community work: This is exceptional. If the maintainers of pypdf see people
  being super helpful in answering issues / discussions or being very active on
  Stackoverflow, we also consider them being contributors to pypdf.

Contributors can add themselves or ask via an GitHub Issue to be added.

Please use the following format:

```
* Last name, First name: 140-characters of text; links to LinkedIn / GitHub / other profiles and personal pages are ok
```

OR

```
* GitHub Username: 140-characters of text; links to LinkedIn / GitHub / other profiles and personal pages are ok
```

and add the entry in the alphabetical order. The 140 characters are everything visible after the `Name:`.

Please don't use images.
